4.6. umbra.components.addons.traceUi.models — Umbra 1.0.8 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »

# 4.6. umbra.components.addons.traceUi.models

models.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines the `umbra.components.factory.traceUi.traceUi.TraceUi` Component Interface class Models.

Others:

## 4.6.1. Module Attributes

`umbra.components.addons.traceUi.models.` `LOGGER`

## 4.6.2. Classes

class `umbra.components.addons.traceUi.models.` `ModulesModel`(parent=None, rootNode=None, horizontalHeaders=None, verticalHeaders=None, defaultNode=None)

  Bases: `umbra.ui.models.GraphModel`

  This class defines the Model used the by `umbra.components.factory.traceUi.traceUi.TraceUi` Component Interface class.

  Parameters: | parent – Object parent. ( QObject ) rootNode – Root node. ( AbstractCompositeNode ) horizontalHeaders – Headers. ( OrderedDict ) verticalHeaders – Headers. ( OrderedDict ) defaultNode – Default node. ( GraphModelNode )

  `initializeModel`(rootNode)

    This method initializes the Model using given root node.

    Parameters: | rootNode – Graph root node. ( DefaultNode )
    Returns: | Method success ( Boolean )

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »